==> haskell-yesod-test-1.6.5.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.5.1
id: yesod-test-1.6.5.1-9LMjjXsNbefL5RXtANrHSP
key: yesod-test-1.6.5.1-9LMjjXsNbefL5RXtANrHSP
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: fdbd9612c49fbb31941a68f68d475269
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.6.1/site-local/yesod-test-1.6.5.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/yesod-test-1.6.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/yesod-test-1.6.5.1
hs-libraries: HSyesod-test-1.6.5.1-9LMjjXsNbefL5RXtANrHSP
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-W55jLnl9KQ9ftt8MpwW6m bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    conduit-1.3.1-KVXSRHbsNfjAMraP9AIqVV containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hspec-core-2.5.5-L3I0MZQ3aCCDiQnLDqJabp
    html-conduit-1.3.2-3KhgOlhG5jL64Kl7N14rgd
    http-types-0.12.2-C9KZRLhMVcD2n7bFrgmpLb
    network-2.7.0.2-AhHTxdUIBGH70CptKdvDEL
    pretty-show-1.8.2-5y0qfXXNaFSEpsDWOG7qzx text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0 wai-3.2.1.2-8YWlKOvZvORGFhSq5FqDWO
    wai-extra-3.0.24.3-2wDq4eMvN9UBrvcLdIrnV5
    xml-conduit-1.8.0.1-3q2bdv10fsS8LGKtql9fuU
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
    yesod-core-1.6.8.1-3UD0ipQINDQCCTyfAuL7G5
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.5.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.5.1
id: yesod-test-1.6.5.1-LBQ7w8y53z16UDFpx3IEhv
key: yesod-test-1.6.5.1-LBQ7w8y53z16UDFpx3IEhv
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: 03feb21a509fb48701c7b6a119dda607
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.6.1/site-local/yesod-test-1.6.5.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/yesod-test-1.6.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/yesod-test-1.6.5.1
hs-libraries: HSyesod-test-1.6.5.1-LBQ7w8y53z16UDFpx3IEhv
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-4nZ0gaFaE644t1em3oPaiM bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    conduit-1.3.1-2hedDM8RkfyGc8ZcxJJZlx containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hspec-core-2.5.5-8ffIqrKM0UK1zENGS8eoPf
    html-conduit-1.3.2-IDbtVK3SNsz2UFQXgZt563
    http-types-0.12.2-7y1WXD0L0v0C6qVqQcEAzr
    network-2.7.0.2-2yr2pvLPehY6oGeYQ5TSho
    pretty-show-1.8.2-5y0qfXXNaFSEpsDWOG7qzx text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0 wai-3.2.1.2-LdgUrNCaqjt5DN2blwIkDh
    wai-extra-3.0.24.3-DcG7m5RldwJ9HiB9rDMJam
    xml-conduit-1.8.0.1-8qjwSxEio51IzFpNFEGMeZ
    xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
    yesod-core-1.6.8.1-8nV6ZNbnH1O8dapURtGZPH
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
